@@ -31,11 +31,9 @@ class Function():
         try:
             result = self.execute()
         except Exception as e:
-            self.logger.error(e)
-            # signalize exception on GUI
-            result = e
+            guiexc = GuiException(e)
+            self.return_queue.put(guiexc)
 
-        return result
 
 class Record():
 
@@ -53,6 +51,15 @@ class Record():
         #logging.debug('__getstate__() called Record')
         return(self.data, self.message)
 
+
+class PythonicError:
+
+    def __init__(self, msg : str) -> None:
+        self.msg = msg
+    
+    def  __str__(self) -> str:
+        return 'Error: {}'.format(self.msg)
+
 class GuiCMD:
     
     def __init__(self, text):
@@ -64,6 +71,10 @@ class GuiCMD:
     def __getstate__(self):
         return(self.text)
 
+class GuiException:
+
+    def __init__(self, e : Exception) -> None:
+        self.e = e
 
 class ProcCMD:
 
