@@ -10,9 +10,9 @@ from PySide2.QtCore import QCoreApplication, QObject, QThread, Qt, QRunnable, QT
 
 
 try:
-    from element_types import Record, ProcCMD, GuiCMD
+    from element_types import Record, ProcCMD, GuiCMD, GuiException, PythonicError
 except ImportError:    
-    from Pythonic.element_types import Record, ProcCMD, GuiCMD
+    from Pythonic.element_types import Record, ProcCMD, GuiCMD, GuiException, PythonicError
 
 
 
@@ -47,15 +47,16 @@ class ProcessHandler(QRunnable):
             self.cmd_queue    = queue.Queue()
 
         try:
-
             # This affects only first invocation
             module = __import__(self.element['Filename'])
+
             #logging.warning("Load module first time")
-            
+
             # Reload to execute possible changes
             module = reload(module) 
 
             elementCls = getattr(module, 'Element')
+            logging.debug('ProcessHandler::run() X5 -id: 0x{:08x}, ident: {:04d}'.format(self.element['Id'], self.identifier))
 
         except Exception as e:
             logging.warning('ProcessHandler::run() - Error loading file - id: 0x{:08x}, ident: {:04d} - {} Error: {}'.format(
@@ -176,7 +177,7 @@ class OperatorStartAll(QRunnable):
 
 class OperatorElementOpDone(QRunnable):
 
-    def __init__(self, config, id, record, identifier, operator):
+    def __init__(self, config, id, record : Record, identifier, operator):
         super(OperatorElementOpDone, self).__init__()
 
 
@@ -193,8 +194,13 @@ class OperatorElementOpDone(QRunnable):
 
         cfgElement = [x for x in self.currentConfig if x['Id'] == self.id][0]
 
+
+
         if cfgElement['Config']['GeneralConfig']['Logging'] and self.record.message: # Log Message enabled
-            logging.info('{} - {}'.format(cfgElement['ObjectName'], self.record.message))
+            if isinstance(self.record.data, PythonicError):
+                logging.warning('{} - {}'.format(cfgElement['ObjectName'], self.record.message))
+            else:
+                logging.info('{} - {}'.format(cfgElement['ObjectName'], self.record.message))
 
             data = {
                 'Id'        : cfgElement['Id'],
@@ -516,6 +522,22 @@ class Operator(QObject):
             }
             self.command.emit(cmd)
             return
+
+        if isinstance(record, GuiException):
+
+            address = {
+                'target'    : 'Element',  
+                'id'        : id,
+                'area'      : area            
+            }
+            cmd = { 
+                'cmd'       : 'ElementException',
+                'address'   : address
+            }
+            # log critical exceptions from multiprocessed elements
+            logging.error(repr(record.e))
+            self.command.emit(cmd)
+            return
         
         operationDoneRunnable = OperatorElementOpDone(self.currentConfig, id, record, identifier, self)
 
